Generative Lexicon (lexigen.py)
===============================

   |

These functions allow for controlled random sampling of words from Project Datamuse's API.

.. automodule:: generativepoetry.lexigen
   :members:

